@@ -30,7 +30,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(
 );
 
-our $VERSION = do { my @r = (q$Revision: 1.7 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+our $VERSION = do { my @r = (q$Revision: 1.8 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 # Preloaded methods go here.
 
@@ -176,9 +176,7 @@ sub make_upload_request(%) {
 		$args{photo} = [ $args{photo} ];
 	}
 
-	return POST $uri,
-		'Content_Type' => 'form-data',
-		'Content' => [ %args ];
+	return POST $uri, 'Content_Type' => 'form-data', 'Content' => \%args;
 }
 
 =head2 upload_request
